@@ -19,7 +19,7 @@ from strenum import StrEnum
 
 class Proxy(db.Model, SerializerMixin):
     id = db.Column(db.Integer, primary_key=True, autoincrement=True)
-    child_id = db.Column(db.Integer, db.ForeignKey('child.id'))
+    child_id = db.Column(db.Integer, db.ForeignKey('child.id'),default=0)
     name = db.Column(db.String(200), nullable=False, unique=True)
     enable = db.Column(db.Boolean, nullable=False)
     proto = db.Column(db.String(200), nullable=False)
