@@ -33,8 +33,8 @@ class DomainAdmin(AdminLTEModelView):
         domain=_("domain.description"),
         mode=_("Direct mode means you want to use your server directly (for usual use), CDN means that you use your server on behind of a CDN provider."),
         cdn_ip=_("config.cdn_forced_host.description"),
-        show_domains=_('You can select the configs with which domains show be shown in the user area. If you select all, automatically, all the new domains will be added for each users.')
-        # current_usage_GB="in GB"
+        show_domains=_('You can select the configs with which domains show be shown in the user area. If you select all, automatically, all the new domains will be added for each users.'),
+        alias=_('The name shown in the configs for this domain.')
     )
     
     # create_modal = True
@@ -49,7 +49,7 @@ class DomainAdmin(AdminLTEModelView):
             'validators': [Regexp(r"(^((25[0-5]|(2[0-4]|1\d|[1-9]|)\d).){3}(25[0-5]|(2[0-4]|1\d|[1-9]|)\d)$)|^([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})$|^[a-fA-F0-9:]+$", message=__("Invalid IP or domain"))]
         }
     }
-    column_list = ["domain", "mode", "domain_ip", "cdn_ip"]
+    column_list = ["domain", "mode","alias", "domain_ip", "cdn_ip"]
     # column_editable_list=["domain"]
     # column_filters=["domain","mode"]
     # form_excluded_columns=['work_with']
@@ -59,10 +59,11 @@ class DomainAdmin(AdminLTEModelView):
         "mode": _("domain.mode"),
         "cdn_ip": _("config.cdn_forced_host.label"),
         'domain_ip': _('domain.ip'),
-        'show_domains':_('Show Domains')
+        'show_domains':_('Show Domains'),
+        'alias':_('Alias')
     }
 
-    form_columns=['domain','mode','cdn_ip','show_domains']
+    form_columns=['domain','alias','mode','cdn_ip','show_domains']
 
     def _domain_admin_link(view, context, model, name):
         if model.mode==DomainType.fake:
@@ -141,8 +142,8 @@ class DomainAdmin(AdminLTEModelView):
             model.show_domains=[]
         # model.work_with = self.session.query(Domain).filter(
         #     Domain.id.in_(work_with_ids)).all()
-
-        hiddify.flash_config_success(restart_mode='apply', domain_changed=True)
+        if Domain.query.filter(Domain.domain==model.domain).count == 0:
+            hiddify.flash_config_success(restart_mode='apply', domain_changed=True)
 
     # def after_model_change(self,form, model, is_created):
     #     if model.show_domains.count==0:
